@@ -2,7 +2,7 @@
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1996-2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
@@ -369,7 +369,7 @@ lzo_bool x_decompress(file_t *fip, file_t *fop,
 //
 **************************************************************************/
 
-void x_filter(lzo_byte *p, lzo_uint l, const header_t *h)
+void x_filter(lzo_bytep p, lzo_uint l, const header_t *h)
 {
     unsigned f = (unsigned) h->filter;
     lzo_bool c = (opt_cmd == CMD_COMPRESS);
@@ -391,8 +391,4 @@ void x_filter(lzo_byte *p, lzo_uint l, const header_t *h)
 }
 
 
-
-/*
-vi:ts=4:et
-*/
-
+/* vim:set ts=4 sw=4 et: */
