@@ -2,7 +2,7 @@
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1996-2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
@@ -27,25 +27,51 @@
 
 
 #ifndef __LZOP_CONF_H
-#define __LZOP_CONF_H
+#define __LZOP_CONF_H 1
 
+#if defined(_WIN32)
+/* disable silly warnings about using "deprecated" POSIX functions like fopen() */
+#ifndef _CRT_NONSTDC_NO_DEPRECATE
+#define _CRT_NONSTDC_NO_DEPRECATE 1
+#endif
+#ifndef _CRT_NONSTDC_NO_WARNINGS
+#define _CRT_NONSTDC_NO_WARNINGS 1
+#endif
+#ifndef _CRT_SECURE_NO_DEPRECATE
+#define _CRT_SECURE_NO_DEPRECATE 1
+#endif
+#ifndef _CRT_SECURE_NO_WARNINGS
+#define _CRT_SECURE_NO_WARNINGS 1
+#endif
+#endif
+
+#if defined(LZOP_HAVE_CONFIG_H)
+#  include <config.h>
+#endif
 #if !defined(PACKAGE)
 #  define PACKAGE "lzop"
 #endif
 
-#define WITH_LZO
-#include <lzoconf.h>
+#define WITH_LZO 1
+#if defined(WITH_LZO)
+#if defined(HAVE_LZO_LZOCONF_H) && defined(HAVE_LZO_LZO1X_H)
+#  include <lzo/lzoconf.h>
+#  include <lzo/lzo1x.h>
+#elif defined(HAVE_LZOCONF_H) && defined(HAVE_LZO1X_H)
+#  include <lzoconf.h>
+#  include <lzo1x.h>
+#elif !defined(LZOP_HAVE_CONFIG_H)
+#  include <lzo/lzoconf.h>
+#  include <lzo/lzo1x.h>
+#else
+#  include <lzoconf.h>
+#  include <lzo1x.h>
+#endif
 #if !defined(LZO_VERSION)
 #  error "you need the LZO library"
-#elif (LZO_VERSION < 0x1040)
-#  error "please upgrade your LZO package"
-#elif (LZO_VERSION >= 0x1080)
-#  include <lzoutil.h>
+#elif (LZO_VERSION < 0x2080) && 0
+#  error "please upgrade your LZO package to version 2.08 or newer"
 #endif
-
-/* workaround a cpp bug under hpux 10.20 */
-#if !defined(LZO_0xffffffffL)
-#  define LZO_0xffffffffL   4294967295ul
 #endif
 
 
@@ -54,29 +80,31 @@
 **************************************************************************/
 
 #if defined(LZOP_HAVE_CONFIG_H)
-#  define ACC_CONFIG_HEADER <config.h>
+#  define ACC_CONFIG_NO_HEADER 1
 #endif
-#include "acc.h"
-#include "acc_ince.h"
+#define ACC_WANT_ACC_INCD_H 1
+#define ACC_WANT_ACC_INCE_H 1
+#define ACC_WANT_ACC_LIB_H 1
+#include "miniacc.h"
+#undef ACC_WANT_ACC_INCD_H
+#undef ACC_WANT_ACC_INCE_H
+#undef ACC_WANT_ACC_LIB_H
 
 /* we _always_ compile lzop with assertions on */
 #undef NDEBUG
 #include <assert.h>
 
-
-/*************************************************************************
-//
-**************************************************************************/
-
-#undef USE_MALLOC
-#if defined(WITH_LZO)
-#  define USE_MALLOC
-#  undef malloc
-#  undef free
-#  define malloc        lzo_malloc
-#  define free          lzo_free
+#if defined(acc_int64l_t)
+#  define lzop_long_t       acc_int64l_t
+#  define lzop_ulong_t      acc_uint64l_t
 #else
-#  error
+#  define lzop_long_t       long int
+#  define lzop_ulong_t      unsigned long int
+#endif
+
+#if (ACC_CC_MSC && (_MSC_VER >= 1400))
+   /* avoid warnings when using "deprecated" POSIX functions */
+#  pragma warning(disable: 4996)
 #endif
 
 
@@ -85,32 +113,32 @@
 **************************************************************************/
 
 #if defined(ACC_OS_EMX)
-#  define DOSISH
+#  define DOSISH 1
 #  define F_OS          (_osmode == 0 ? F_OS_FAT : F_OS_OS2)
 #  define F_CS          (_osmode == 0 ? F_CS_DOS : F_CS_NATIVE)
 #elif (ACC_OS_DOS16 || ACC_OS_DOS32)
-#  define DOSISH
+#  define DOSISH 1
 #  define F_OS          F_OS_FAT
 #  define F_CS          F_CS_DOS
 #elif (ACC_OS_OS216 || ACC_OS_OS2)
-#  define DOSISH
+#  define DOSISH 1
 #  define F_OS          F_OS_OS2
 #elif (ACC_OS_TOS)
-#  define DOSISH
+#  define DOSISH 1
 #  define F_OS          F_OS_ATARI
 #elif (ACC_OS_WIN16)
-#  define DOSISH
+#  define DOSISH 1
 #  define F_OS          F_OS_FAT
 #  define F_CS          F_CS_WIN16
 #elif (ACC_OS_WIN32 || ACC_OS_WIN64 || ACC_OS_CYGWIN)
-#  define DOSISH
+#  define DOSISH 1
 #  define F_OS          F_OS_VFAT
 #  define F_CS          F_CS_WIN32
 #endif
 
 
 #if defined(DOSISH)
-#  define OPT_NAME_DEFAULT
+#  define OPT_NAME_DEFAULT 1
 #  if !defined(DIR_SEP)
 #    define DIR_SEP         "/\\"
 #  endif
@@ -161,9 +189,7 @@
 **************************************************************************/
 
 #if defined(__DJGPP__)
-#  define NO_SETMODE
-#  define USE__READ
-#  define USE__WRITE
+#  define NO_SETMODE 1
 #  if ((__DJGPP__ * 100 + __DJGPP_MINOR__) < 203)
 #    error "need djgpp 2.03 or above"
 #  endif
@@ -175,16 +201,16 @@
 
 #if defined(ACC_OS_TOS)
 #  if defined(__MINT__)
-#  elif defined(__PUREC__)
+#  elif (ACC_CC_PUREC || ACC_CC_TURBOC)
 #    include <ext.h>
-#    define O_EXCL_BROKEN
+#    define O_EXCL_BROKEN 1
 #    if !defined(S_IFMT)
 #      if defined(S_IFREG) && defined(S_IFDIR) && defined(S_IFCHR)
 #        define S_IFMT      (S_IFREG | S_IFDIR | S_IFCHR)
 #      endif
 #    endif
 #  else
-#    error
+#    error "FIXME"
 #  endif
 #endif
 
@@ -196,21 +222,6 @@
 //
 **************************************************************************/
 
-#ifndef LZO_UTYPE_MAX
-/* Maximum value of a signed/unsigned type.
-   Do not use casts, avoid overflows. */
-#define LZO_STYPE_MAX(b)    (((1l  << (8*(b)-2)) - 1l)  + (1l  << (8*(b)-2)))
-#define LZO_UTYPE_MAX(b)    (((1ul << (8*(b)-1)) - 1ul) + (1ul << (8*(b)-1)))
-#endif
-
-#if !defined(SIZE_T_MAX)
-#  if defined(SIZEOF_SIZE_T)
-#    define SIZE_T_MAX      LZO_UTYPE_MAX(SIZEOF_SIZE_T)
-#  else
-#    define SIZE_T_MAX      UINT_MAX
-#  endif
-#endif
-
 #if !defined(PATH_MAX)
 #  define PATH_MAX          512
 #elif (PATH_MAX < 512)
@@ -223,9 +234,8 @@
 #  define RETSIGTYPE        void
 #endif
 #ifndef SIGTYPEENTRY
-#  define SIGTYPEENTRY
+#  define SIGTYPEENTRY      /*empty*/
 #endif
-typedef RETSIGTYPE (SIGTYPEENTRY *sig_type)(int);
 
 #if !defined(MODE_T)
 #if defined(SIZEOF_MODE_T) && (SIZEOF_MODE_T > 0)
@@ -252,19 +262,12 @@ typedef RETSIGTYPE (SIGTYPEENTRY *sig_type)(int);
 #  define memset            lzo_memset
 #endif
 
-#if !defined(HAVE_STRCASECMP)
-#  if defined(HAVE_STRICMP)
-#    define strcasecmp      stricmp
-#  else
-#    define strcasecmp      strcmp
-#  endif
+
+#if !defined(HAVE_STRCASECMP) && defined(HAVE_STRICMP)
+#  define strcasecmp        stricmp
 #endif
-#if !defined(HAVE_STRNCASECMP)
-#  if defined(HAVE_STRNICMP)
-#    define strncasecmp     strnicmp
-#  else
-#    define strncasecmp     strncmp
-#  endif
+#if !defined(HAVE_STRNCASECMP) && defined(HAVE_STRNICMP)
+#  define strncasecmp       strnicmp
 #endif
 
 
@@ -295,14 +298,14 @@ typedef RETSIGTYPE (SIGTYPEENTRY *sig_type)(int);
 #  if defined(S_IFMT) && defined(S_IFREG)
 #    define S_ISREG(m)  (((m) & S_IFMT) == S_IFREG)
 #  else
-#    error S_ISREG
+#    error "S_ISREG"
 #  endif
 #endif
 #if !defined(S_ISDIR)
 #  if defined(S_IFMT) && defined(S_IFDIR)
 #    define S_ISDIR(m)  (((m) & S_IFMT) == S_IFDIR)
 #  else
-#    error S_ISDIR
+#    error "S_ISDIR"
 #  endif
 #endif
 #if !defined(S_ISCHR)
@@ -330,7 +333,7 @@ typedef RETSIGTYPE (SIGTYPEENTRY *sig_type)(int);
 #define ALIGN_UP(a,b)   ALIGN_DOWN((a) + ((b) - 1), b)
 
 #undef UNUSED
-#define UNUSED          ACC_UNUSED
+#define UNUSED(var)     ACC_UNUSED(var)
 
 
 /*************************************************************************
@@ -388,6 +391,8 @@ extern int opt_crc32;
 extern lzo_bool opt_decompress_safe;
 extern int opt_force;
 extern int opt_name;
+#define MAX_NUM_THREADS 64
+extern int opt_num_threads;
 extern const char *opt_output_name;
 extern lzo_bool opt_optimize;
 extern lzo_bool opt_path;
@@ -422,12 +427,12 @@ typedef struct
 
     int opt_name;
     unsigned long part;
-    unsigned long bytes_read;
-    unsigned long bytes_written;
+    lzop_ulong_t bytes_read;
+    lzop_ulong_t bytes_written;
     lzo_bool warn_multipart;
     lzo_bool warn_unknown_suffix;
 
-    unsigned long bytes_processed;
+    lzop_ulong_t bytes_processed;
 
 #define FILE_T_NAME_LEN     ( 2*((PATH_MAX)+1) + SUFFIX_MAX + 1 )
     char name[ FILE_T_NAME_LEN ];
@@ -501,8 +506,8 @@ typedef struct
     lzo_uint32 flags;
     lzo_uint32 filter;
     lzo_uint32 mode;
-    lzo_uint32 mtime;
-    lzo_uint32 gmtdiff;
+    lzo_uint32 mtime_low;
+    lzo_uint32 mtime_high;
     lzo_uint32 header_checksum;
 
     lzo_uint32 extra_field_len;
@@ -536,11 +541,11 @@ void write32(file_t *ft, lzo_uint32 v);
 void init_compress_header(header_t *h, const file_t *fip, const file_t *fop);
 void write_header(file_t *ft, const header_t *h);
 
-void do_test(const header_t *h, unsigned long d_len, unsigned long c_len);
+void do_test(const header_t *h, lzop_ulong_t d_len, lzop_ulong_t c_len);
 void do_test_total(void);
-void do_info(const header_t *h, unsigned long d_len, unsigned long c_len);
-void do_ls(const header_t *h, unsigned long d_len, unsigned long c_len);
-void do_list(const header_t *h, unsigned long d_len, unsigned long c_len);
+void do_info(const header_t *h, lzop_ulong_t d_len, lzop_ulong_t c_len);
+void do_ls(const header_t *h, lzop_ulong_t d_len, lzop_ulong_t c_len);
+void do_list(const header_t *h, lzop_ulong_t d_len, lzop_ulong_t c_len);
 void do_list_total(void);
 
 
@@ -552,12 +557,12 @@ lzo_bool x_enter(const header_t *h);
 void x_leave(const header_t *h);
 
 lzo_bool x_compress(file_t *fip, file_t *fop, header_t *h);
-lzo_bool x_decompress(file_t *fip, file_t *fop, const header_t *h, lzo_bool);
+lzo_bool x_decompress(file_t *fip, file_t *fop, const header_t *h, lzo_bool skip);
 
 int x_get_method(header_t *h);
 int x_set_method(int m, int l);
 
-void x_filter(lzo_byte *p, lzo_uint l, const header_t *h);
+void x_filter(lzo_bytep p, lzo_uint l, const header_t *h);
 
 
 /*************************************************************************
@@ -570,7 +575,7 @@ lzo_bool lzo_enter(const header_t *h);
 void lzo_leave(const header_t *h);
 
 lzo_bool lzo_compress(file_t *fip, file_t *fop, const header_t *h);
-lzo_bool lzo_decompress(file_t *fip, file_t *fop, const header_t *h, lzo_bool);
+lzo_bool lzo_decompress(file_t *fip, file_t *fop, const header_t *h, lzo_bool skip);
 
 int lzo_get_method(header_t *h);
 int lzo_set_method(int m, int l);
@@ -579,18 +584,33 @@ void lzo_init_compress_header(header_t *h);
 #endif
 
 
+/*************************************************************************
+// p_lzo_mt.c
+**************************************************************************/
+
+#if defined(WITH_LZO) && defined(WITH_THREADS)
+
+lzo_bool lzo_threaded_enter(const header_t *h);
+void lzo_threaded_leave(const header_t *h);
+
+lzo_bool lzo_threaded_compress(file_t *fip, file_t *fop, const header_t *h);
+lzo_bool lzo_threaded_decompress(file_t *fip, file_t *fop, const header_t *h, lzo_bool skip);
+
+#endif
+
+
 /*************************************************************************
 // filter.c
 **************************************************************************/
 
-void t_sub1(lzo_byte *p, lzo_uint l);
-void t_add1(lzo_byte *p, lzo_uint l);
+void t_sub1(lzo_bytep p, lzo_uint l);
+void t_add1(lzo_bytep p, lzo_uint l);
 
-void t_sub(lzo_byte *p, lzo_uint l, int n);
-void t_add(lzo_byte *p, lzo_uint l, int n);
+void t_sub(lzo_bytep p, lzo_uint l, int n);
+void t_add(lzo_bytep p, lzo_uint l, int n);
 
-void t_mtf(lzo_byte *p, lzo_uint l);
-void t_unmtf(lzo_byte *p, lzo_uint l);
+void t_mtf(lzo_bytep p, lzo_uint l);
+void t_unmtf(lzo_bytep p, lzo_uint l);
 
 
 /*************************************************************************
@@ -599,21 +619,19 @@ void t_unmtf(lzo_byte *p, lzo_uint l);
 
 typedef struct
 {
-    lzo_byte    *mem_alloc;
-    lzo_byte    *mem;
-    lzo_uint32  size_alloc;
-    lzo_uint32  size;
-    lzo_uint32  align;
-    lzo_uint32  flags;
+    /* public */
+    lzo_bytep   mb_mem;
+    lzo_uint32  mb_size;
+    /* private */
+    lzo_bytep   mb_mem_alloc;
+    lzo_uint32  mb_size_alloc;
+    lzo_uint32  mb_align;
 }
-memblock_t;
-#define memblock_p      memblock_t *
+mblock_t;
+#define mblock_p      mblock_t *
 
-lzo_bool mb_alloc(memblock_p m, lzo_uint32 size, lzo_uint align);
-void mb_free(memblock_p m);
-
-lzo_bool mb_init(memblock_p m, lzo_uint32 size, lzo_uint align,
-                 lzo_voidp heap, lzo_uint32 heap_size);
+lzo_bool mb_alloc(mblock_p m, lzo_uint32 size, lzo_uint32 align);
+void mb_free(mblock_p m);
 
 
 /*************************************************************************
@@ -638,8 +656,10 @@ char *fn_strlwr(char *n);
 int fn_strcmp(const char *n1, const char *n2);
 lzo_bool fn_is_same_file(const char *n1, const char *n2);
 int fn_has_suffix(const char *name);
-int fn_cleanpath(const char *name, char *newname, size_t size);
+int fn_cleanpath(const char *name, char *newname, size_t size, int flags);
 
+time_t fix_time(time_t t);
+time_t get_mtime(const header_t *h);
 #if defined(HAVE_LOCALTIME)
 void tm2str(char *s, size_t size, const struct tm *tmp);
 #endif
@@ -661,9 +681,9 @@ char *maybe_rename_file(const char *original_name);
 // other globals
 **************************************************************************/
 
+extern const char lzop_rcsid[];
 extern const char *progname;
 extern MODE_T u_mask;
-extern lzo_byte __lzo_copyright[];
 extern time_t current_time;
 
 void sysinfo(void);
@@ -682,42 +702,12 @@ void sysinfo_djgpp(void);
 
 #if defined(WITH_LZO)
 
-#include <lzo1x.h>
-
-#define USE_LZO1X_1
-#if !defined(LZO_999_UNSUPPORTED)
-#  define USE_LZO1X_999
+#define USE_LZO1X_1 1
+#if 1
+#  define USE_LZO1X_999 1
 #endif
 #if !defined(ACC_OS_DOS16)
-#  define USE_LZO1X_1_15
-#endif
-
-#if defined(LZO_USE_ASM_1)
-LZO_EXTERN_CDECL(int)
-lzo1x_decompress_asm_fast
-                        ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
-                                lzo_voidp wrkmem /* NOT USED */ );
-LZO_EXTERN_CDECL(int)
-lzo1x_decompress_asm_fast_safe
-                        ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
-                                lzo_voidp wrkmem /* NOT USED */ );
-#  define lzo1x_decompress          lzo1x_decompress_asm_fast
-#  define lzo1x_decompress_safe     lzo1x_decompress_asm_fast_safe
-#elif defined(LZO_USE_ASM_2)
-LZO_EXTERN_CDECL(int)
-_lzo1x_decompress_asm_fast
-                        ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
-                                lzo_voidp wrkmem /* NOT USED */ );
-LZO_EXTERN_CDECL(int)
-_lzo1x_decompress_asm_fast_safe
-                        ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
-                                lzo_voidp wrkmem /* NOT USED */ );
-#  define lzo1x_decompress          _lzo1x_decompress_asm_fast
-#  define lzo1x_decompress_safe     _lzo1x_decompress_asm_fast_safe
+#  define USE_LZO1X_1_15 1
 #endif
 
 #endif /* WITH_LZO */
@@ -733,7 +723,4 @@ _lzo1x_decompress_asm_fast_safe
 #endif /* already included */
 
 
-/*
-vi:ts=4:et
-*/
-
+/* vim:set ts=4 sw=4 et: */
