@@ -2,9 +2,8 @@
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
    and/or modify them under the terms of the GNU General Public License as
@@ -19,14 +18,15 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
+   http://www.oberhumer.com/opensource/lzop/
  */
 
 
-#include "lzop.h"
+#include "conf.h"
 
 #if defined(__DJGPP__)
 
@@ -42,26 +42,28 @@
 unsigned _stklen = 65536;
 
 
-/* This is called before `main'. */
-static void __attribute__((constructor))
+/* This is called before 'main'. */
+static void __attribute__((__constructor__))
 djgpp_startup (void)
 {
-	const char *s;
+    const char *s;
+    static char lfn_y[] = "LFN=y";
+    static char lfn_n[] = "LFN=n";
 
-	s = getenv("LZOP_LFN");
-	if (s == NULL || (s[0] != 'n' && s[0] != 'N'))
-		putenv("LFN=y");
-	else
-	{
-		putenv("LFN=n");
-  		_crt0_startup_flags |= _CRT0_FLAG_NO_LFN;
-	}
+    s = getenv("LZOP_LFN");
+    if (s == NULL || (s[0] != 'n' && s[0] != 'N'))
+        putenv(lfn_y);
+    else
+    {
+        putenv(lfn_n);
+        _crt0_startup_flags |= _CRT0_FLAG_NO_LFN;
+    }
 
-	_djstat_flags |= _STAT_INODE;
-	_djstat_flags |= _STAT_EXEC_EXT;
-	_djstat_flags |= _STAT_EXEC_MAGIC;
-	_djstat_flags |= _STAT_DIRSIZE;
-	_djstat_flags |= _STAT_ROOT_TIME;
+    _djstat_flags |= _STAT_INODE;
+    _djstat_flags |= _STAT_EXEC_EXT;
+    _djstat_flags |= _STAT_EXEC_MAGIC;
+    _djstat_flags |= _STAT_DIRSIZE;
+    _djstat_flags |= _STAT_ROOT_TIME;
 }
 
 
@@ -72,10 +74,10 @@ void __crt0_load_environment_file(char *app_name) { UNUSED(app_name); }
 /* No need for this function */
 int _is_executable(const char *filename, int fhandle, const char *extension)
 {
-	UNUSED(filename);
-	UNUSED(fhandle);
-	UNUSED(extension);
-	return 0;
+    UNUSED(filename);
+    UNUSED(fhandle);
+    UNUSED(extension);
+    return 0;
 }
 
 
@@ -115,68 +117,62 @@ typedef struct {
 
 static void meminfo(void)
 {
-	__dpmi_free_mem_info info;
-	const unsigned long err = (unsigned long) -1;
-	unsigned long ps = 0;
-	unsigned long k;
+    __dpmi_free_mem_info info;
+    const unsigned long err = (unsigned long) -1;
+    unsigned long ps = 0;
+    unsigned long k;
 
-	if (__dpmi_get_page_size(&ps) != 0 || ps <= 0)
-		return;
-	if (__dpmi_get_free_memory_information(&info) != 0)
-		return;
+    if (__dpmi_get_page_size(&ps) != 0 || ps <= 0)
+        return;
+    if (__dpmi_get_free_memory_information(&info) != 0)
+        return;
 
 #if 0
-	k = info.largest_available_free_block_in_bytes;
-	if (k == err)
-	{
+    k = info.largest_available_free_block_in_bytes;
+    if (k == err)
+    {
         k = info.maximum_unlocked_page_allocation_in_pages;
         if (k != err)
             k *= ps;
         else
             k = info.largest_available_free_block_in_bytes;
-        k = err;
-	}
-	phys = k;
+    }
 #endif
 
-	k = info.total_number_of_physical_pages;
-	k = info.total_number_of_unlocked_pages;
-	k = info.total_number_of_free_pages;
-	k = (k == err) ? err : k * ps;
-	if (k != err)
-	{
-		k /= 1024;
-		con_fprintf(con_term,"DPMI physical memory available: %6ld kB\n",k);
-	}
+#if 0
+    k = info.total_number_of_physical_pages;
+    k = info.total_number_of_unlocked_pages;
+#endif
+    k = info.total_number_of_free_pages;
+    if (k != err)
+    {
+        k = (k * ps) / 1024;
+        con_fprintf(con_term,"DPMI physical memory available: %6ld kB\n",k);
+    }
 
-	k = info.maximum_unlocked_page_allocation_in_pages;
-	k = (k == err) ? err : k * ps;
-	if (k != err)
-	{
-		k /= 1024;
-		con_fprintf(con_term,"DPMI virtual memory available:  %6ld kB\n",k);
-	}
-	con_fprintf(con_term,"\n");
+    k = info.maximum_unlocked_page_allocation_in_pages;
+    if (k != err)
+    {
+        k = (k * ps) / 1024;
+        con_fprintf(con_term,"DPMI virtual memory available:  %6ld kB\n",k);
+    }
+    con_fprintf(con_term,"\n");
 }
 
 
 void sysinfo_djgpp(void)
 {
-	meminfo();
+    meminfo();
 
-	if (_USE_LFN)
-		con_fprintf(con_term,"Long filenames are supported.\n");
-	else
-		con_fprintf(con_term,"Long filenames are not supported.\n");
-	con_fprintf(con_term,"\n");
+    if (_USE_LFN)
+        con_fprintf(con_term,"Long filenames are supported.\n");
+    else
+        con_fprintf(con_term,"Long filenames are not supported.\n");
+    con_fprintf(con_term,"\n");
 }
 
 
-
 #endif /* __DJGPP__ */
 
 
-/*
-vi:ts=4
-*/
-
+/* vim:set ts=4 sw=4 et: */
