@@ -1,8 +1,8 @@
-/* p_lzo.c --
+/* p_lzo.c -- LZO compression
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1996-2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
@@ -134,7 +134,7 @@ void lzo_init_compress_header(header_t *h)
 // memory setup
 **************************************************************************/
 
-#if defined(ACC_OS_DOS16) && !defined(__DPMI16__)
+#if defined(ACC_OS_DOS16) && !defined(ACC_ARCH_I086PM)
 #  define BLOCK_SIZE        (128*1024l)
 #else
 #  define BLOCK_SIZE        (256*1024l)
@@ -152,36 +152,25 @@ void lzo_init_compress_header(header_t *h)
 #endif
 
 
-#if 1 && defined(USE_MALLOC)
+#if 1
 #  define ALIGN_SIZE    4096
 #else
 #  define ALIGN_SIZE    1
 #endif
 
-/* LZO may expand uncompressible data by a small amount */
+/* LZO may expand incompressible data by a small amount */
 #define MAX_COMPRESSED_SIZE(x)  ((x) + (x) / 16 + 64 + 3)
 
-#if !defined(USE_MALLOC)
-#define LSIZE(size) \
-    ALIGN_UP((size) + (ALIGN_SIZE > 1 ? ALIGN_SIZE - 1 : 0), sizeof(long))
-#define HEAP_ALLOC(var,size) \
-    long __LZO_MMODEL var [ LSIZE(size) / sizeof(long) ]
-static HEAP_ALLOC(heap_block1, BLOCK_SIZE);
-static HEAP_ALLOC(heap_block2, MAX_COMPRESSED_SIZE(BLOCK_SIZE));
-static HEAP_ALLOC(heap_wrkmem, WRK_LEN);
-#endif
 
-
-static memblock_t block1;
-static memblock_t block2;
-static memblock_t wrkmem;
+static mblock_t blocks[2];
+static mblock_t wrkmem;
 
 
 static void free_mem(void)
 {
     mb_free(&wrkmem);
-    mb_free(&block2);
-    mb_free(&block1);
+    mb_free(&blocks[1]);
+    mb_free(&blocks[0]);
 }
 
 
@@ -189,15 +178,9 @@ static lzo_bool alloc_mem(lzo_uint32 s1, lzo_uint32 s2, lzo_uint32 w)
 {
     lzo_bool r = 1;
 
-#if defined(USE_MALLOC)
-    r &= mb_alloc(&block1, s1, ALIGN_SIZE);
-    r &= mb_alloc(&block2, s2, ALIGN_SIZE);
+    r &= mb_alloc(&blocks[0], s1, ALIGN_SIZE);
+    r &= mb_alloc(&blocks[1], s2, ALIGN_SIZE);
     r &= mb_alloc(&wrkmem, w,  ALIGN_SIZE);
-#else
-    r &= mb_init(&block1, s1, ALIGN_SIZE, heap_block1, sizeof(heap_block1));
-    r &= mb_init(&block2, s2, ALIGN_SIZE, heap_block2, sizeof(heap_block2));
-    r &= mb_init(&wrkmem, w,  ALIGN_SIZE, heap_wrkmem, sizeof(heap_wrkmem));
-#endif
     if (!r)
         free_mem();
     return r;
@@ -209,22 +192,26 @@ static lzo_bool alloc_mem(lzo_uint32 s1, lzo_uint32 s2, lzo_uint32 w)
 **************************************************************************/
 
 /* maybe make this an option ? */
-static const lzo_uint block_size = BLOCK_SIZE;
+static const lzo_uint32 block_size = BLOCK_SIZE;
 
 lzo_bool lzo_enter(const header_t *h)
 {
     int r;
     lzo_uint32 wrk_len;
 
+#if defined(WITH_THREADS)
+    if (opt_num_threads > 1)
+        return lzo_threaded_enter(h);
+#endif
+
     if (h != NULL)
     {
-#if !defined(NDEBUG)
-        if (h->flags & F_ADLER32_C)
-            { assert(h->flags & F_ADLER32_D); }
-        if (h->flags & F_CRC32_C)
-            { assert(h->flags & F_CRC32_D); }
-#endif
-        return 1;
+        r = 1;
+        if ((h->flags & F_ADLER32_C) && !(h->flags & F_ADLER32_D))
+            { r = 0; assert(h->flags & F_ADLER32_D); }
+        if ((h->flags & F_CRC32_C) && !(h->flags & F_CRC32_D))
+            { r = 0; assert(h->flags & F_CRC32_D); }
+        return r;
     }
 
 #if 0
@@ -277,6 +264,12 @@ lzo_bool lzo_enter(const header_t *h)
 
 void lzo_leave(const header_t *h)
 {
+#if defined(WITH_THREADS)
+    if (opt_num_threads > 1) {
+        lzo_threaded_leave(h);
+        return;
+   }
+#endif
     if (h == NULL)
         free_mem();
 }
@@ -289,19 +282,25 @@ void lzo_leave(const header_t *h)
 lzo_bool lzo_compress(file_t *fip, file_t *fop, const header_t *h)
 {
     int r = LZO_E_OK;
-    lzo_byte * const b1 = block1.mem;
-    lzo_byte * const b2 = block2.mem;
-    lzo_uint32 src_len = 0, dst_len = 0;
+    lzo_bytep const b1 = blocks[0].mb_mem;
+    lzo_bytep const b2 = blocks[1].mb_mem;
+    lzo_uint32 src_len = 0;
+    lzo_uint dst_len = 0;
     lzo_uint32 c_adler32 = ADLER32_INIT_VALUE, d_adler32 = ADLER32_INIT_VALUE;
     lzo_uint32 c_crc32 = CRC32_INIT_VALUE, d_crc32 = CRC32_INIT_VALUE;
     lzo_int l;
     lzo_bool ok = 1;
 
+#if defined(WITH_THREADS)
+    if (opt_num_threads > 1)
+        return lzo_threaded_compress(fip, fop, h, skip);
+#endif
+
     for (;;)
     {
         /* read a block */
         l = read_buf(fip, b1, block_size);
-        src_len = (l > 0 ? l : 0);
+        src_len = (lzo_uint32) (l > 0 ? l : 0);
 
         /* write uncompressed block size */
         write32(fop,src_len);
@@ -320,16 +319,16 @@ lzo_bool lzo_compress(file_t *fip, file_t *fop, const header_t *h)
 
         /* compress */
         if (h->method == M_LZO1X_1)
-            r = lzo1x_1_compress(b1, src_len, b2, &dst_len, wrkmem.mem);
+            r = lzo1x_1_compress(b1, src_len, b2, &dst_len, wrkmem.mb_mem);
 #if defined(USE_LZO1X_1_15)
         else if (h->method == M_LZO1X_1_15)
             r = lzo1x_1_15_compress(b1, src_len,
-                                    b2, &dst_len, wrkmem.mem);
+                                    b2, &dst_len, wrkmem.mb_mem);
 #endif
 #if defined(USE_LZO1X_999)
         else if (h->method == M_LZO1X_999)
             r = lzo1x_999_compress_level(b1, src_len,
-                                         b2, &dst_len, wrkmem.mem,
+                                         b2, &dst_len, wrkmem.mb_mem,
                                          NULL, 0, 0, h->level);
 #endif
         else
@@ -338,14 +337,14 @@ lzo_bool lzo_compress(file_t *fip, file_t *fop, const header_t *h)
 #if 0
         fprintf(stderr, "%ld %ld %ld\n", (long)src_len, (long)dst_len, (long)block2.size);
 #endif
-        assert(dst_len <= block2.size);
+        assert(dst_len <= blocks[1].mb_size);
         if (r != LZO_E_OK)
             fatal(fip,"Internal error - compression failed");
 
         /* optimize */
         if (opt_optimize && dst_len < src_len)
         {
-            lzo_uint32 new_len = src_len;
+            lzo_uint new_len = src_len;
             r = lzo1x_optimize(b2, dst_len, b1, &new_len, NULL);
             if (r != LZO_E_OK || new_len != src_len)
                 fatal(fip,"Internal error - optimization failed");
@@ -353,9 +352,9 @@ lzo_bool lzo_compress(file_t *fip, file_t *fop, const header_t *h)
 
         /* write compressed block size */
         if (dst_len < src_len)
-            write32(fop,dst_len);
+            write32(fop, (lzo_uint32) dst_len);
         else
-            write32(fop,src_len);
+            write32(fop, src_len);
 
         /* write checksum of uncompressed block */
         if (h->flags & F_ADLER32_D)
@@ -394,21 +393,26 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
                         const header_t *h, lzo_bool skip)
 {
     int r;
-    lzo_uint src_len, dst_len;
+    lzo_uint32 src_len, dst_len;
     lzo_uint32 c_adler32 = ADLER32_INIT_VALUE, d_adler32 = ADLER32_INIT_VALUE;
     lzo_uint32 c_crc32 = CRC32_INIT_VALUE, d_crc32 = CRC32_INIT_VALUE;
     lzo_bool ok = 1;
     lzo_bool use_seek;
-    memblock_t * const block = &block2;
-    lzo_byte * b1;
-    lzo_byte * const b2 = block->mem;
+    mblock_t * const block = &blocks[1];
+    lzo_bytep b1;
+    lzo_bytep const b2 = block->mb_mem;
+
+#if defined(WITH_THREADS)
+    if (opt_num_threads > 1)
+        return lzo_threaded_decompress(fip, fop, h, skip);
+#endif
 
     use_seek = skip || opt_cmd == CMD_LIST || opt_cmd == CMD_LS ||
                        opt_cmd == CMD_INFO;
 
     for (;;)
     {
-        lzo_byte *dst;
+        lzo_bytep dst;
 
         /* read uncompressed block size */
         read32(fip,&dst_len);
@@ -418,7 +422,7 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
             break;
 
         /* error if split file */
-        if (dst_len == 0xffffffffL)
+        if (dst_len == 0xffffffffUL)
         {
             /* should not happen - not yet implemented */
             error(fip,"this file is a split " PACKAGE " file");
@@ -447,10 +451,10 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
         if (dst_len > block_size)
         {
             /* should not happen - not yet implemented */
-            fatal(fip,"block size too small -- use option `--blocksize'");
+            fatal(fip,"block size too small -- use option '--blocksize'");
             ok = 0; break;
         }
-        assert(block->size >= src_len);
+        assert(block->mb_size >= src_len);
 
         /* read checksum of uncompressed block */
         if (h->flags & F_ADLER32_D)
@@ -481,7 +485,7 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
         }
 
         /* read the block */
-        b1 = block->mem + block->size - src_len;
+        b1 = block->mb_mem + block->mb_size - src_len;
         if (use_seek && fip->fd != STDIN_FILENO)
         {
             if (lseek(fip->fd, src_len, SEEK_CUR) == -1)
@@ -499,7 +503,7 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
             fop->bytes_processed += dst_len;
             continue;
         }
-        assert(block->size >= MAX_COMPRESSED_SIZE(dst_len));
+        assert(block->mb_size >= MAX_COMPRESSED_SIZE(dst_len));
 
         /* verify checksum of compressed block */
         if (opt_checksum && (h->flags & F_ADLER32_C))
@@ -525,7 +529,7 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
 
         if (src_len < dst_len)
         {
-            lzo_uint32 d = dst_len;
+            lzo_uint d = dst_len;
 
             /* decompress */
             if (opt_decompress_safe)
@@ -585,7 +589,4 @@ lzo_bool lzo_decompress(file_t *fip, file_t *fop,
 #endif /* WITH_LZO */
 
 
-/*
-vi:ts=4:et
-*/
-
+/* vim:set ts=4 sw=4 et: */
