@@ -2,7 +2,7 @@
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1996-2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
@@ -28,8 +28,6 @@
 
 #include "conf.h"
 
-#include "acc_lib.ch"
-
 
 /*************************************************************************
 // filename util
@@ -156,7 +154,7 @@ int fn_has_suffix(const char *name)
 }
 
 
-int fn_cleanpath(const char *name, char *newname, size_t size)
+int fn_cleanpath(const char *name, char *newname, size_t size, int flags)
 {
     size_t l = 0;
     size_t n = 0;
@@ -175,15 +173,23 @@ int fn_cleanpath(const char *name, char *newname, size_t size)
             n++;
         if (n - last_n == 2 && name[n-2] == '.' && name[n-1] == '.')
         {
-            while (l > 0)
+            if (flags & 1)
+                return -2;
+            while (l > 0) {
                 if (newname[--l] == '/')
                 {
                     --slashes;
                     break;
                 }
+            }
             /* newname[l] = 0; printf("del %s\n", newname); */
         }
-        else if (!(n - last_n == 1 && name[n-1] == '.'))
+        else if (n - last_n == 1 && name[n-1] == '.')
+        {
+            if (flags & 2)
+                return -3;
+        }
+        else
         {
             if (l > 0)
                 { ++slashes; add('/'); }
@@ -204,18 +210,38 @@ int fn_cleanpath(const char *name, char *newname, size_t size)
 // time util
 **************************************************************************/
 
+time_t fix_time(time_t t)
+{
+    if (t == (time_t) -1)
+        t = 0;
+    return t;
+}
+
+time_t get_mtime(const header_t *h)
+{
+    lzop_ulong_t t;
+    t = h->mtime_high;
+    t <<= 16; t <<= 16;
+    t |= h->mtime_low;
+    return t == (lzop_ulong_t)(time_t)t ? (time_t)t : (time_t)0;
+}
+
+
 #if defined(HAVE_LOCALTIME)
 void tm2str(char *s, size_t size, const struct tm *tmp)
 {
     assert(size >= 18);
 #if defined(HAVE_SNPRINTF)
     snprintf(s, size, "%04d-%02d-%02d %02d:%02d:%02d",
-#else
-    sprintf(s, "%04d-%02d-%02d %02d:%02d:%02d",
-#endif
             (int) tmp->tm_year + 1900, (int) tmp->tm_mon + 1,
             (int) tmp->tm_mday,
             (int) tmp->tm_hour, (int) tmp->tm_min, (int) tmp->tm_sec);
+#else
+    sprintf(s, "%04d-%02d-%02d %02d:%02d:%02d",
+            (int) tmp->tm_year + 1900, (int) tmp->tm_mon + 1,
+            (int) tmp->tm_mday,
+            (int) tmp->tm_hour, (int) tmp->tm_min, (int) tmp->tm_sec);
+#endif
 }
 #endif
 
@@ -243,7 +269,12 @@ void time2ls(char *s, size_t size, const time_t *t)
 #if defined(HAVE_LOCALTIME) && defined(HAVE_STRFTIME)
     const char *fmt = "%b %e  %Y";
 #if defined(HAVE_DIFFTIME)
-    const double d = difftime(current_time,*t);
+#  if (ACC_OS_DOS16)
+    /* do not introduce any floating point dependencies */
+    long d = (long)current_time - (long)*t;
+#  else
+    const double d = difftime(current_time, *t);
+#  endif
     if (d <= 6 * 30 * 24 * 3600L && d >= -3600L)
         fmt = "%b %e %H:%M";
 #endif
@@ -253,6 +284,7 @@ void time2ls(char *s, size_t size, const time_t *t)
 #else
     s[0] = 0;
     UNUSED(size);
+    UNUSED(t);
 #endif
 }
 
@@ -470,8 +502,8 @@ void mode_string(MODE_T m, char *str)
    return it instead.  Return NULL if the rename failed (shouldn't happen).
 
    The file name changes are: (1) any name that is reserved by a DOS
-   device driver (such as `prn.txt' or `aux.c') is prepended with a `_';
-   and (2) illegal characters are replaced with `_' or `-' (well, almost;
+   device driver (such as 'prn.txt' or 'aux.c') is prepended with a '_';
+   and (2) illegal characters are replaced with '_' or '-' (well, almost;
    look at the code below for details).  */
 
 #define is_slash(x)     fn_is_sep(x)
@@ -585,14 +617,14 @@ char *maybe_rename_file(const char *original_name)
 
         /* The list of character devices is not constant: it depends on
          what device drivers did they install in their CONFIG.SYS.
-         `stat' will tell us if the basename of the file name is a
+         'stat' will tell us if the basename of the file name is a
          characer device.  */
         while (stat(base, &st_buf) == 0 && S_ISCHR(st_buf.st_mode))
         {
             size_t blen = strlen(base);
 
             /* I don't believe any DOS character device names begin with a
-             `_'.  But in case they invent such a device, let us try twice.  */
+             '_'.  But in case they invent such a device, let us try twice.  */
             if (++i > 2)
                 return (char *)0;
 
@@ -609,7 +641,41 @@ char *maybe_rename_file(const char *original_name)
 #endif /* DOSISH */
 
 
-/*
-vi:ts=4:et
-*/
+/*************************************************************************
+//
+**************************************************************************/
 
+#if (ACC_CC_MSC && (_MSC_VER >= 1000 && _MSC_VER < 1200))
+   /* avoid '-W4' warnings in <windows.h> */
+#  pragma warning(disable: 4201 4214 4514)
+#endif
+#if (ACC_CC_MSC && (_MSC_VER >= 1300))
+   /* avoid '-Wall' warnings in <windows.h> */
+#  pragma warning(disable: 4255)
+#endif
+
+#define ACC_WANT_ACC_INCI_H 1
+#define ACC_WANT_ACCLIB_GETOPT 1
+#define ACC_WANT_ACCLIB_HALLOC 1
+#define ACC_WANT_ACCLIB_HMEMCPY 1
+#define ACC_WANT_ACCLIB_HSREAD 1
+#define ACC_WANT_ACCLIB_MISC 1
+#define ACC_WANT_ACCLIB_WILDARGV 1
+#if (ACC_HAVE_MM_HUGE_PTR)
+#  define ACC_WANT_ACCLIB_HREAD 1
+#endif
+#include "miniacc.h"
+#undef ACC_WANT_ACC_INCI_H
+#undef ACC_WANT_ACCLIB_HALLOC
+#undef ACC_WANT_ACCLIB_MISC
+#undef ACC_WANT_ACCLIB_WILDARGV
+#undef ACC_WANT_ACCLIB_HREAD
+
+#if (__ACCLIB_REQUIRE_HMEMCPY_CH) && !defined(__ACCLIB_HMEMCPY_CH_INCLUDED)
+#  define ACC_WANT_ACCLIB_HMEMCPY 1
+#  include "acc/acclib/hmemcpy.ch"
+#  undef ACC_WANT_ACCLIB_HMEMCPY
+#endif
+
+
+/* vim:set ts=4 sw=4 et: */
